==> querydsl-parser-0.2-sources.jar: foundation/jpa/querydsl/StateRPar16.java <==
package foundation.jpa.querydsl;

import foundation.rpg.parser.UnexpectedInputException;
import foundation.rpg.parser.Named;

import java.util.Arrays;
import java.util.List;

// Generated visitor pattern based state for grammar parser.
public class StateRPar16 extends StackState<foundation.rpg.common.symbols.RPar, StackState<java.util.List<com.querydsl.core.types.Expression>, StackState<foundation.rpg.common.symbols.LPar, StackState<foundation.rpg.common.symbols.Identifier, StackState<foundation.rpg.common.symbols.Dot, StackState<java.lang.Object, ? extends State>>>>>> {

// NoStack:
// Stack:
    public StateRPar16(foundation.jpa.querydsl.QueryFactory factory, foundation.rpg.common.symbols.RPar node, StackState<java.util.List<com.querydsl.core.types.Expression>, StackState<foundation.rpg.common.symbols.LPar, StackState<foundation.rpg.common.symbols.Identifier, StackState<foundation.rpg.common.symbols.Dot, StackState<java.lang.Object, ? extends State>>>>> prev) {
        super(factory, node, prev);
    }


// Reduce:
    @Override
    public State visitRPar(foundation.rpg.common.symbols.RPar symbol) throws UnexpectedInputException {
        StackState<java.util.List<com.querydsl.core.types.Expression>, StackState<foundation.rpg.common.symbols.LPar, StackState<foundation.rpg.common.symbols.Identifier, StackState<foundation.rpg.common.symbols.Dot, StackState<java.lang.Object, ? extends State>>>>> stack1 = this.getPrev();
		StackState<foundation.rpg.common.symbols.LPar, StackState<foundation.rpg.common.symbols.Identifier, StackState<foundation.rpg.common.symbols.Dot, StackState<java.lang.Object, ? extends State>>>> stack2 = stack1.getPrev();
		StackState<foundation.rpg.common.symbols.Identifier, StackState<foundation.rpg.common.symbols.Dot, StackState<java.lang.Object, ? extends State>>> stack3 = stack2.getPrev();
		StackState<foundation.rpg.common.symbols.Dot, StackState<java.lang.Object, ? extends State>> stack4 = stack3.getPrev();
		StackState<java.lang.Object, ? extends State> stack5 = stack4.getPrev();
		State stack6 = stack5.getPrev();
        return stack6.visitObject(getFactory().is(stack5.getNode(), stack4.getNode(), stack3.getNode(), stack2.getNode(), stack1.getNode(), this.getNode())).visitRPar(symbol);
    }

    @Override
    public State visitOr(foundation.rpg.common.symbols.Or symbol) throws UnexpectedInputException {
        StackState<java.util.List<com.querydsl.core.types.Expression>, StackState<foundation.rpg.common.symbols.LPar, StackState<foundation.rpg.common.symbols.Identifier, StackState<foundation.rpg.common.symbols.Dot, StackState<java.lang.Object, ? extends State>>>>> stack1 = this.getPrev();
		StackState<foundation.rpg.common.symbols.LPar, StackState<foundation.rpg.common.symbols.Identifier, StackState<foundation.rpg.common.symbols.Dot, StackState<java.lang.Object, ? extends State>>>> stack2 = stack1.getPrev();
		StackState<foundation.rpg.common.symbols.Identifier, StackState<foundation.rpg.common.symbols.Dot, StackState<java.lang.Object, ? extends State>>> stack3 = stack2.getPrev();
		StackState<foundation.rpg.common.symbols.Dot, StackState<java.lang.Object, ? extends State>> stack4 = stack3.getPrev();
		StackState<java.lang.Object, ? extends State> stack5 = stack4.getPrev();
		State stack6 = stack5.getPrev();
        return stack6.visitObject(getFactory().is(stack5.getNode(), stack4.getNode(), stack3.getNode(), stack2.getNode(), stack1.getNode(), this.getNode())).visitOr(symbol);
    }

    @Override
    public State visitAnd(foundation.rpg.common.symbols.And symbol) throws UnexpectedInputException {
        StackState<java.util.List<com.querydsl.core.types.Expression>, StackState<foundation.rpg.common.symbols.LPar, StackState<foundation.rpg.common.symbols.Identifier, StackState<foundation.rpg.common.symbols.Dot, StackState<java.lang.Object, ? extends State>>>>> stack1 = this.getPrev();
		StackState<foundation.rpg.common.symbols.LPar, StackState<foundation.rpg.common.symbols.Identifier, StackState<foundation.rpg.common.symbols.Dot, StackState<java.lang.Object, ? extends State>>>> stack2 = stack1.getPrev();
		StackState<foundation.rpg.common.symbols.Identifier, StackState<foundation.rpg.common.symbols.Dot, StackState<java.lang.Object, ? extends State>>> stack3 = stack2.getPrev();
		StackState<foundation.rpg.common.symbols.Dot, StackState<java.lang.Object, ? extends State>> stack4 = stack3.getPrev();
		StackState<java.lang.Object, ? extends State> stack5 = stack4.getPrev();
		State stack6 = stack5.getPrev();
        return stack6.visitObject(getFactory().is(stack5.getNode(), stack4.getNode(), stack3.getNode(), stack2.getNode(), stack1.getNode(), this.getNode())).visitAnd(symbol);
    }

    @Override
    public State visitDot(foundation.rpg.common.symbols.Dot symbol) throws UnexpectedInputException {
        StackState<java.util.List<com.querydsl.core.types.Expression>, StackState<foundation.rpg.common.symbols.LPar, StackState<foundation.rpg.common.symbols.Identifier, StackState<foundation.rpg.common.symbols.Dot, StackState<java.lang.Object, ? extends State>>>>> stack1 = this.getPrev();
		StackState<foundation.rpg.common.symbols.LPar, StackState<foundation.rpg.common.symbols.Identifier, StackState<foundation.rpg.common.symbols.Dot, StackState<java.lang.Object, ? extends State>>>> stack2 = stack1.getPrev();
		StackState<foundation.rpg.common.symbols.Identifier, StackState<foundation.rpg.common.symbols.Dot, StackState<java.lang.Object, ? extends State>>> stack3 = stack2.getPrev();
		StackState<foundation.rpg.common.symbols.Dot, StackState<java.lang.Object, ? extends State>> stack4 = stack3.getPrev();
		StackState<java.lang.Object, ? extends State> stack5 = stack4.getPrev();
		State stack6 = stack5.getPrev();
        return stack6.visitObject(getFactory().is(stack5.getNode(), stack4.getNode(), stack3.getNode(), stack2.getNode(), stack1.getNode(), this.getNode())).visitDot(symbol);
    }


// Shift:
// Accept:
    @Override
    public List<Object> stack() {
        StackState<java.util.List<com.querydsl.core.types.Expression>, StackState<foundation.rpg.common.symbols.LPar, StackState<foundation.rpg.common.symbols.Identifier, StackState<foundation.rpg.common.symbols.Dot, StackState<java.lang.Object, ? extends State>>>>> stack1 = this.getPrev();
		StackState<foundation.rpg.common.symbols.LPar, StackState<foundation.rpg.common.symbols.Identifier, StackState<foundation.rpg.common.symbols.Dot, StackState<java.lang.Object, ? extends State>>>> stack2 = stack1.getPrev();
		StackState<foundation.rpg.common.symbols.Identifier, StackState<foundation.rpg.common.symbols.Dot, StackState<java.lang.Object, ? extends State>>> stack3 = stack2.getPrev();
		StackState<foundation.rpg.common.symbols.Dot, StackState<java.lang.Object, ? extends State>> stack4 = stack3.getPrev();
		StackState<java.lang.Object, ? extends State> stack5 = stack4.getPrev();
		State stack6 = stack5.getPrev();
        return Arrays.asList(stack5.getNode(), stack4.getNode(), stack3.getNode(), stack2.getNode(), stack1.getNode(), this.getNode());
    }

}

==> querydsl-parser-0.6-sources.jar: foundation/jpa/querydsl/StateRPar16.java <==
package foundation.jpa.querydsl;

import foundation.rpg.parser.UnexpectedInputException;
import foundation.rpg.parser.Named;

import java.util.Arrays;
import java.util.List;

// Generated visitor pattern based state for grammar parser.
public class StateRPar16 extends StackState<foundation.rpg.common.symbols.RPar, StackState<java.util.List<com.querydsl.core.types.Expression>, StackState<foundation.rpg.common.symbols.LPar, StackState<foundation.rpg.common.symbols.Identifier, StackState<foundation.rpg.common.symbols.Dot, StackState<java.lang.Object, ? extends State>>>>>> {

// NoStack:
// Stack:
    public StateRPar16(foundation.jpa.querydsl.QueryFactory factory, foundation.rpg.common.symbols.RPar node, StackState<java.util.List<com.querydsl.core.types.Expression>, StackState<foundation.rpg.common.symbols.LPar, StackState<foundation.rpg.common.symbols.Identifier, StackState<foundation.rpg.common.symbols.Dot, StackState<java.lang.Object, ? extends State>>>>> prev) {
        super(factory, node, prev);
    }


// Reduce:
    @Override
    public State visitEnd(foundation.rpg.parser.End symbol) throws UnexpectedInputException {
        StackState<java.util.List<com.querydsl.core.types.Expression>, StackState<foundation.rpg.common.symbols.LPar, StackState<foundation.rpg.common.symbols.Identifier, StackState<foundation.rpg.common.symbols.Dot, StackState<java.lang.Object, ? extends State>>>>> stack1 = this.getPrev();
		StackState<foundation.rpg.common.symbols.LPar, StackState<foundation.rpg.common.symbols.Identifier, StackState<foundation.rpg.common.symbols.Dot, StackState<java.lang.Object, ? extends State>>>> stack2 = stack1.getPrev();
		StackState<foundation.rpg.common.symbols.Identifier, StackState<foundation.rpg.common.symbols.Dot, StackState<java.lang.Object, ? extends State>>> stack3 = stack2.getPrev();
		StackState<foundation.rpg.common.symbols.Dot, StackState<java.lang.Object, ? extends State>> stack4 = stack3.getPrev();
		StackState<java.lang.Object, ? extends State> stack5 = stack4.getPrev();
		State stack6 = stack5.getPrev();
        return stack6.visitObject(getFactory().is(stack5.getNode(), stack4.getNode(), stack3.getNode(), stack2.getNode(), stack1.getNode(), this.getNode())).visitEnd(symbol);
    }

    @Override
    public State visitOr(foundation.rpg.common.symbols.Or symbol) throws UnexpectedInputException {
        StackState<java.util.List<com.querydsl.core.types.Expression>, StackState<foundation.rpg.common.symbols.LPar, StackState<foundation.rpg.common.symbols.Identifier, StackState<foundation.rpg.common.symbols.Dot, StackState<java.lang.Object, ? extends State>>>>> stack1 = this.getPrev();
		StackState<foundation.rpg.common.symbols.LPar, StackState<foundation.rpg.common.symbols.Identifier, StackState<foundation.rpg.common.symbols.Dot, StackState<java.lang.Object, ? extends State>>>> stack2 = stack1.getPrev();
		StackState<foundation.rpg.common.symbols.Identifier, StackState<foundation.rpg.common.symbols.Dot, StackState<java.lang.Object, ? extends State>>> stack3 = stack2.getPrev();
		StackState<foundation.rpg.common.symbols.Dot, StackState<java.lang.Object, ? extends State>> stack4 = stack3.getPrev();
		StackState<java.lang.Object, ? extends State> stack5 = stack4.getPrev();
		State stack6 = stack5.getPrev();
        return stack6.visitObject(getFactory().is(stack5.getNode(), stack4.getNode(), stack3.getNode(), stack2.getNode(), stack1.getNode(), this.getNode())).visitOr(symbol);
    }

    @Override
    public State visitAnd(foundation.rpg.common.symbols.And symbol) throws UnexpectedInputException {
        StackState<java.util.List<com.querydsl.core.types.Expression>, StackState<foundation.rpg.common.symbols.LPar, StackState<foundation.rpg.common.symbols.Identifier, StackState<foundation.rpg.common.symbols.Dot, StackState<java.lang.Object, ? extends State>>>>> stack1 = this.getPrev();
		StackState<foundation.rpg.common.symbols.LPar, StackState<foundation.rpg.common.symbols.Identifier, StackState<foundation.rpg.common.symbols.Dot, StackState<java.lang.Object, ? extends State>>>> stack2 = stack1.getPrev();
		StackState<foundation.rpg.common.symbols.Identifier, StackState<foundation.rpg.common.symbols.Dot, StackState<java.lang.Object, ? extends State>>> stack3 = stack2.getPrev();
		StackState<foundation.rpg.common.symbols.Dot, StackState<java.lang.Object, ? extends State>> stack4 = stack3.getPrev();
		StackState<java.lang.Object, ? extends State> stack5 = stack4.getPrev();
		State stack6 = stack5.getPrev();
        return stack6.visitObject(getFactory().is(stack5.getNode(), stack4.getNode(), stack3.getNode(), stack2.getNode(), stack1.getNode(), this.getNode())).visitAnd(symbol);
    }

    @Override
    public State visitDot(foundation.rpg.common.symbols.Dot symbol) throws UnexpectedInputException {
        StackState<java.util.List<com.querydsl.core.types.Expression>, StackState<foundation.rpg.common.symbols.LPar, StackState<foundation.rpg.common.symbols.Identifier, StackState<foundation.rpg.common.symbols.Dot, StackState<java.lang.Object, ? extends State>>>>> stack1 = this.getPrev();
		StackState<foundation.rpg.common.symbols.LPar, StackState<foundation.rpg.common.symbols.Identifier, StackState<foundation.rpg.common.symbols.Dot, StackState<java.lang.Object, ? extends State>>>> stack2 = stack1.getPrev();
		StackState<foundation.rpg.common.symbols.Identifier, StackState<foundation.rpg.common.symbols.Dot, StackState<java.lang.Object, ? extends State>>> stack3 = stack2.getPrev();
		StackState<foundation.rpg.common.symbols.Dot, StackState<java.lang.Object, ? extends State>> stack4 = stack3.getPrev();
		StackState<java.lang.Object, ? extends State> stack5 = stack4.getPrev();
		State stack6 = stack5.getPrev();
        return stack6.visitObject(getFactory().is(stack5.getNode(), stack4.getNode(), stack3.getNode(), stack2.getNode(), stack1.getNode(), this.getNode())).visitDot(symbol);
    }


// Shift:
// Accept:
    @Override
    public List<Object> stack() {
        StackState<java.util.List<com.querydsl.core.types.Expression>, StackState<foundation.rpg.common.symbols.LPar, StackState<foundation.rpg.common.symbols.Identifier, StackState<foundation.rpg.common.symbols.Dot, StackState<java.lang.Object, ? extends State>>>>> stack1 = this.getPrev();
		StackState<foundation.rpg.common.symbols.LPar, StackState<foundation.rpg.common.symbols.Identifier, StackState<foundation.rpg.common.symbols.Dot, StackState<java.lang.Object, ? extends State>>>> stack2 = stack1.getPrev();
		StackState<foundation.rpg.common.symbols.Identifier, StackState<foundation.rpg.common.symbols.Dot, StackState<java.lang.Object, ? extends State>>> stack3 = stack2.getPrev();
		StackState<foundation.rpg.common.symbols.Dot, StackState<java.lang.Object, ? extends State>> stack4 = stack3.getPrev();
		StackState<java.lang.Object, ? extends State> stack5 = stack4.getPrev();
		State stack6 = stack5.getPrev();
        return Arrays.asList(stack5.getNode(), stack4.getNode(), stack3.getNode(), stack2.getNode(), stack1.getNode(), this.getNode());
    }

}
